# slackr
Slackr

Setup

** Application can only run on OSX **

1. docker-compose up -d.
2. Open Kibana and verify interface is available at http://localhost:5601
3. pip install all requirements.
3. Run the python init file under slackr.
4. Click on kibana dashboard "Apps usage" to view your app usages.